OC.L10N.register(
    "calendar",
    {
    "Calendar" : "Lịch",
    "%s has published the calendar »%s«" : "%s vừa đăng tải thông tin vào lịch »%s«",
    "Hello," : "Xin chào,",
    "We wanted to inform you that %s has published the calendar »%s«." : "Chúng tôi muốn thông báo với bạn rằng %s vừa đăng tải thông tin vào lịch calendar »%s«.",
    "Open »%s«" : "Mở »%s«",
    "Cheers!" : "Xin chúc mừng!",
    "Recipient" : "Người nhận",
    "Too many redirects. Aborting ..." : "Có quá nhiều điều hướng ngược. Đang loại bỏ ...",
    "The remote server did not give us access to the calendar (HTTP {%s} error)" : "Máy chủ từ xa không cho chúng tôi truy cập vào lịch  (Lỗi HTTP {%s} )",
    "Error connecting to remote server" : "Lỗi khi kết nối từ máy chủ từ xa.",
    "Error requesting resource on remote server. This could possible be related to a certificate mismatch" : "Lỗi khi yêu cầu cung cấp tài nguyên trên máy chủ từ xa. Điều này có thể liên quan đến không hợp lệ về chứng thư số.",
    "Error requesting resource on remote server" : "Lỗi khi yêu cầu tài nguyên trên máy chủ từ xa",
    "Individual" : "Cá nhân",
    "Group" : "N",
    "Resource" : "Tài nguyên",
    "Room" : "Phòng",
    "Unknown" : " Chưa biết",
    "Required" : "Bắt buộc",
    "Optional" : "Tùy chọn",
    "Does not attend" : "Không tham dự",
    "{name} ({email})" : "{name} ({email})",
    "You are in an unknown timezone ({tz}), falling back to UTC" : "Không rõ bạn đang ở múi giờ nào ({tz}), chuyển lại múi giờ UTC",
    "Please create a calendar first." : "Xin vui lòng tạo một lịch làm việc trước.",
    "New event" : "Sự kiện mới",
    "CalDAV address for clients" : "Địa chỉ CalDAV cho người dùng đầu cuối",
    "Share Calendar" : "Chia sẻ lịch",
    "Shared" : "Được chia sẻ",
    "WebDAV address for subscriptions" : "Địa chỉ WebDAV cho các đăng ký",
    "group" : "nhóm",
    "Details" : "Chi tiết",
    "Attendees" : "Người tham gia",
    "Reminders" : "Nhắc nhở",
    "Repeating" : "Lặp",
    "When shared show full event" : "Khi được chia sẻ thì thể hiện đầy đủ sự kiện",
    "When shared show only busy" : "Khi được chia sẻ thì chỉ thể hiện đang bận",
    "When shared hide this event" : "Khi được chia sẻ thì ẩn sự kiện này đi",
    "Confirmed" : "Đã xác nhận",
    "Tentative" : "Chưa chắc chắn",
    "Cancelled" : "Bị hủy",
    "Please add a title." : "Xin vui lòng thêm một tiêu đề",
    "Please select a calendar." : "Xin vui lòng chọn lịch.",
    "The event can not end before it starts." : "Sự kiện này không thể kết thúc trước khi nó bắt đầu.",
    "Global" : "Chung",
    "None" : "Không gì cả",
    "Every day" : "Hàng ngày",
    "Every week" : "Hàng tuần",
    "Every month" : "Hàng tháng",
    "Every year" : "Hàng năm",
    "never" : "không thay đổi",
    "after" : "sau khi",
    "How about getting started by importing some calendars?" : "Làm thế nào về việc bắt đầu bằng cách nhập một số lịch?",
    "At time of event" : "Tại thời điểm sự kiện",
    "5 minutes before" : "Trước 5 phút",
    "10 minutes before" : "Trước 10 phút",
    "15 minutes before" : "Trước 15 phút",
    "30 minutes before" : "Trước 30 phút",
    "1 hour before" : "Trước 1 tiếng",
    "2 hours before" : "Trước 2 tiếng",
    "Custom" : "Tùy chỉnh",
    "Audio" : "Âm thanh",
    "Email" : "Thư điện tử",
    "Pop-up" : "Pop-up",
    "sec" : "giây",
    "min" : "phút",
    "hours" : "giờ",
    "days" : "ngày",
    "week" : "tuần",
    "before" : "trước",
    "start" : "thời gian bắt đầu",
    "end" : "thời gian kết thúc",
    "Editing reminders of unknown type not supported." : "Không hỗ trợ chỉnh sửa lời nhắc thuộc loại không xác định.",
    "Week {number} of {year}" : "Tuần thứ {number} của năm {year}",
    "{type} {time} before the event starts" : "{type} {time} trước khi sự kiện bắt đầu",
    "{type} {time} before the event ends" : "{type} {time} trước khi sự kiện kết thúc",
    "{type} {time} after the event starts" : "{type} {time} sau khi sự kiện bắt đầu",
    "Title of the Event" : "Tên sự kiện",
    "Delete" : "Xóa",
    "Cancel" : "Hủy",
    "Create" : "Tạo",
    "Update" : "Cập nhật",
    "Close" : "Đóng",
    "Location" : "Vị trí",
    "Description" : "Mô tả",
    "Export" : "Xuất ra",
    "Day" : "Ngày",
    "Week" : "Tuần",
    "Month" : "Tháng",
    "Today" : "Hôm nay",
    "More" : "hơn",
    "Edit" : "Sửa",
    "Download" : "Tải về",
    "can edit" : "có thể chỉnh sửa",
    "New Calendar" : "Lịch mới",
    "Name" : "Tên",
    "Edit event" : "Sửa sự kiện",
    "Type" : "Loại",
    "Repeat" : "Lặp lại",
    "Add" : "Thêm",
    "from" : "từ",
    "to" : "đến",
    "New calendar" : "Lịch mới",
    "Primary CalDAV address" : "Địa chỉ CalDAV chính",
    "iOS/OS X CalDAV address" : "iOS/OS X địa chỉ CalDAV"
},
"nplurals=1; plural=0;");
